@@ -8,6 +8,7 @@ import (
 	"reflect"
 	"regexp"
 	"strings"
+	"time"
 
 	"github.com/Azure/azure-sdk-for-go/services/storage/mgmt/2019-04-01/storage"
 	"github.com/Azure/azure-storage-blob-go/azblob"
@@ -24,10 +25,9 @@ import (
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapiv1 "github.com/openshift/api/operator/v1"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 )
 
@@ -122,10 +122,7 @@ func GetConfig(listers *regopclient.Listers) (*Azure, error) {
 // Account. Storage account names must be between 3 and 24 characters in
 // length and use numbers and lower-case letters only.
 func generateAccountName(infrastructureName string) string {
-	prefix := storageAccountInvalidCharRe.ReplaceAllString(infrastructureName, "")
-	if prefix == "" {
-		prefix = "imageregistry"
-	}
+	prefix := "imageregistry" + storageAccountInvalidCharRe.ReplaceAllString(infrastructureName, "")
 	if len(prefix) > 24-5 {
 		prefix = prefix[:24-5]
 	}
@@ -139,7 +136,8 @@ func (d *driver) accountExists(storageAccountsClient storage.AccountsClient, acc
 		storage.AccountCheckNameAvailabilityParameters{
 			Name: to.StringPtr(accountName),
 			Type: to.StringPtr("Microsoft.Storage/storageAccounts"),
-		})
+		},
+	)
 }
 
 func (d *driver) createStorageAccount(storageAccountsClient storage.AccountsClient, resourceGroupName, accountName, location string) error {
@@ -200,7 +198,7 @@ func getStorageContainer(accountName, key, containerName string) (azblob.Contain
 	}
 
 	p := azblob.NewPipeline(c, azblob.PipelineOptions{
-		Telemetry: azblob.TelemetryOptions{Value: parameters.UserAgent},
+		Telemetry: azblob.TelemetryOptions{Value: defaults.UserAgent},
 	})
 
 	u, err := url.Parse(fmt.Sprintf(blobFormatString, accountName))
@@ -257,7 +255,10 @@ func (d *driver) storageAccountsClient(cfg *Azure) (storage.AccountsClient, erro
 
 	storageAccountsClient := storage.NewAccountsClient(cfg.SubscriptionID)
 	storageAccountsClient.Authorizer = auth
-	storageAccountsClient.AddToUserAgent(parameters.UserAgent)
+	storageAccountsClient.PollingDelay = 10 * time.Second
+	storageAccountsClient.PollingDuration = 3 * time.Minute
+	storageAccountsClient.RetryAttempts = 1
+	_ = storageAccountsClient.AddToUserAgent(defaults.UserAgent)
 
 	return storageAccountsClient, nil
 }
@@ -302,7 +303,6 @@ func (d *driver) VolumeSecrets() (map[string]string, error) {
 
 // containerExists determines whether or not an azure container exists
 func (d *driver) containerExists(containerName string) (bool, error) {
-
 	if d.Config.AccountName == "" || d.Config.Container == "" {
 		return false, nil
 	}
@@ -337,7 +337,7 @@ func (d *driver) containerExists(containerName string) (bool, error) {
 	}
 
 	p := azblob.NewPipeline(c, azblob.PipelineOptions{
-		Telemetry: azblob.TelemetryOptions{Value: parameters.UserAgent},
+		Telemetry: azblob.TelemetryOptions{Value: defaults.UserAgent},
 	})
 
 	service := azblob.NewServiceURL(*u, p)
@@ -364,7 +364,7 @@ func (d *driver) StorageExists(cr *imageregistryv1.Config) (bool, error) {
 
 	exists, err := d.containerExists(d.Config.Container)
 	if err != nil {
-		util.UpdateCondition(cr, defaults.StorageExists, operatorapiv1.ConditionFalse, storageExistsReasonAzureError, fmt.Sprintf("%s", err))
+		util.UpdateCondition(cr, defaults.StorageExists, operatorapiv1.ConditionUnknown, storageExistsReasonAzureError, fmt.Sprintf("%s", err))
 		return false, err
 	}
 	if !exists {
